/*
 * Created on 6/20/2014.
 * Copyright (c) 2014 Yahoo Inc. All rights reserved.
 */

precision highp float;

varying vec2		vTexCoords0;

uniform sampler2D	uTexture0;			/* Background texture. */
uniform sampler2D	uTexture1;			/* Fog texture. */
uniform float		uOffsetFront;		/* Offset of the front fog plane, in pixels. */
uniform float		uOffsetBack;		/* Offset of the back fog plane, in pixels. */
uniform vec2		uScaledFogImgDims;	/* (width,height) in pixels, scaled uniformly so orig img height = view height. */
uniform vec2		uScaledFogTexDims;	/* (width,height) in pixels, scaled same as img dims (above). */
uniform vec2		uViewDims;			/* (width,height) in pixels. */
uniform float		uScalarX;			/* Used in calculating horz UV coord. Reduces number of calculations in shader. */
uniform float		uScalarY;			/* Used in calculating vert UV coord. Reduces number of calculations in shader. */
uniform float		uFrontAlpha;		/* Contribution of the front fog layer. */
uniform float		uBackAlpha;			/* Contribution of the back fog layer. */
uniform float		uBackgroundAlpha;	/* Contribution of the background image. */
uniform bool		uFlipped;			/* True if the y-axis (for the fog image) should be flipped. */

/**
 * Fragment shader for the fog-shaded effect using PT vertex format.
 */
void main() {
	
	vec4 bkgColor = texture2D(uTexture0, vTexCoords0);
	float brightness = (bkgColor.r + bkgColor.g + bkgColor.b) / (bkgColor.a * 3.0);
	
/*
	// These lines show how the calculations were made before uScalarX and uScalarY were applied to reduce calculations.
	float frontUVX = (fract((gl_FragCoord.x - uOffsetFront) / uScaledFogImgDims.x) * uScaledFogImgDims.x) / uScaledFogTexDims.x;
	float frontUVY = (((uViewDims.y-gl_FragCoord.y)/uViewDims.y)*uScaledFogImgDims.y) / uScaledFogTexDims.y;
	float backUVX = (fract((gl_FragCoord.x - uOffsetBack) / uScaledFogImgDims.x) * uScaledFogImgDims.x) / uScaledFogTexDims.x;
*/

	float frontUVX = fract((gl_FragCoord.x - uOffsetFront) / uScaledFogImgDims.x) * uScalarX;
	float frontUVY = (uFlipped ? gl_FragCoord.y : uViewDims.y-gl_FragCoord.y) * uScalarY;
	vec4 frontColor = texture2D(uTexture1, vec2(frontUVX, frontUVY));
	
	float backUVX = fract((gl_FragCoord.x - uOffsetBack) / uScaledFogImgDims.x) * uScalarX;
	vec4 backColor = texture2D(uTexture1, vec2(backUVX, frontUVY));
	
	gl_FragColor = uFrontAlpha * frontColor + uBackAlpha * backColor + (uBackgroundAlpha * 0.4 * brightness * vec4(1,1,1,1) + uBackgroundAlpha * 0.6 * bkgColor);
}
