/*
 * Created on 9/3/2014.
 * Copyright(C) Yahoo Inc. All rights reserved.
 */

/*
#ifndef SHOWHEAT
	#define SHOWHEAT 0
#endif
*/

precision mediump float;
const float kSideMargin = 8.0;

varying vec2 vTexCoordBkg;
varying vec2 vTexCoordHeat;
uniform sampler2D uBackgroundTexture;
uniform sampler2D uHeatTexture;
uniform float uOffsetV1;
uniform float uOffsetV2;
uniform float uMaxOffset;
uniform vec2 uBufferSize;
uniform float uMaxEffectFraction;
uniform bool uFlipped;

void main() {
	
	vec2 heatLoc1 = vec2(vTexCoordHeat.x, vTexCoordHeat.y+uOffsetV1);
	vec2 heatLoc2 = vec2(vTexCoordHeat.x, vTexCoordHeat.y+uOffsetV2);
	
	vec4 heatPixel1 = texture2D(uHeatTexture, heatLoc1);
	vec4 heatPixel2 = texture2D(uHeatTexture, heatLoc2);
	float fractionY = (uFlipped ? (uBufferSize.y-gl_FragCoord.y)/uBufferSize.y : gl_FragCoord.y/uBufferSize.y);
	float multiplierY;
	if (fractionY < uMaxEffectFraction) {
		multiplierY = smoothstep(0.0,uMaxEffectFraction, fractionY);
	} else {
		multiplierY = smoothstep(1.0,uMaxEffectFraction, fractionY);
	}
	float multiplierX = 1.0;
	if (gl_FragCoord.x < kSideMargin) {
		multiplierX = gl_FragCoord.x / kSideMargin;
	} else if (gl_FragCoord.x > uBufferSize.x-kSideMargin) {
		multiplierX = (uBufferSize.x-1.0-gl_FragCoord.x) / kSideMargin;
	}
	
	/*
	#if SHOWHEAT
		float alpha = heatPixel2.r;
	#endif
	*/
	float offsetY = -uMaxOffset * 0.5 * multiplierY + heatPixel1.r * uMaxOffset * multiplierY;
	float offsetX = -uMaxOffset * 0.5 * multiplierX + heatPixel2.r * uMaxOffset * multiplierX;
	
	/*
	#if SHOWHEAT
		gl_FragColor = texture2D(uBackgroundTexture, vec2(vTexCoordBkg.x+offsetX, vTexCoordBkg.y+offsetY)) + vec4(1.0,0.0,0.0,1.0) * alpha;
	#else
	*/
		gl_FragColor = texture2D(uBackgroundTexture, vec2(vTexCoordBkg.x+offsetX, vTexCoordBkg.y+offsetY));
	/*
	#endif
	*/
}
